@@ -33,8 +33,6 @@
 #include "command.h"
 #include "util.h"
 
-#define SESSION_STOCK_LOGOUT "session-logout"
-
 static gchar *halt_command[] =
 {
   HALT_COMMAND, NULL
@@ -175,29 +173,6 @@ force_pango_cache_init ()
 	pango_font_description_free (font_desc);
 }
 
-static inline void
-register_logout_stock_item (void)
-{
-	static gboolean registered = FALSE;
-
-	if (!registered) {
-		GtkIconFactory      *factory;
-		GtkIconSet          *quit_icons;
-
-		static GtkStockItem  logout_item [] = {
-			{ SESSION_STOCK_LOGOUT, N_("_Log Out"), 0, 0, GETTEXT_PACKAGE },
-		};
-
-		quit_icons = gtk_icon_factory_lookup_default (GTK_STOCK_QUIT);
-		factory = gtk_icon_factory_new ();
-		gtk_icon_factory_add (factory, SESSION_STOCK_LOGOUT, quit_icons);
-		gtk_icon_factory_add_default (factory);
-		gtk_stock_add_static (logout_item, 1);
-
-		registered = TRUE;
-	}
-}
-
 static gboolean
 display_gui (void)
 {
@@ -209,6 +184,10 @@ display_gui (void)
   GtkWidget *reboot = NULL;
   GtkWidget *invisible;
   gboolean   retval = FALSE;
+  gboolean save_active = FALSE;
+  gboolean halt_active = FALSE;
+  gboolean reboot_active = FALSE;
+  GError *error = NULL;
 
   gsm_verbose ("display_gui: showing logout dialog\n");
 
@@ -240,8 +219,6 @@ display_gui (void)
   XGrabServer (GDK_DISPLAY ());
   iris ();
 
-  register_logout_stock_item ();
-
   box = gtk_message_dialog_new (NULL, 0,
 				GTK_MESSAGE_QUESTION,
 				GTK_BUTTONS_NONE,
@@ -249,7 +226,7 @@ display_gui (void)
 
   gtk_dialog_add_button (GTK_DIALOG (box), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
   gtk_dialog_add_button (GTK_DIALOG (box), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-  gtk_dialog_add_button (GTK_DIALOG (box), SESSION_STOCK_LOGOUT, GTK_RESPONSE_OK);
+  gtk_dialog_add_button (GTK_DIALOG (box), GTK_STOCK_OK, GTK_RESPONSE_OK);
 
   g_object_set (G_OBJECT (box), "type", GTK_WINDOW_POPUP, NULL);
 
@@ -311,6 +288,17 @@ display_gui (void)
 
   response = gtk_dialog_run (GTK_DIALOG (box));
 
+  if (halt)
+    halt_active = GTK_TOGGLE_BUTTON (halt)->active;
+
+  if (reboot)
+    reboot_active = GTK_TOGGLE_BUTTON (reboot)->active;
+
+  if (toggle_button)
+    save_active = GTK_TOGGLE_BUTTON (toggle_button)->active;
+
+  gtk_widget_destroy (box);
+
   refresh_screen ();
   XUngrabServer (GDK_DISPLAY ());
 
@@ -323,16 +311,12 @@ display_gui (void)
     case GTK_RESPONSE_OK:
       /* We want to know if we should trash changes (and lose forever)
        * or save them */
-      if(!autosave)
-        save_selected = GTK_TOGGLE_BUTTON (toggle_button)->active;
-
-      if (halt)
-	{
-	  if (GTK_TOGGLE_BUTTON (halt)->active)
-	    action = HALT;
-	  else if (GTK_TOGGLE_BUTTON (reboot)->active)
-	    action = REBOOT;
-	}
+      if(save_active)
+	save_selected = save_active;
+      if (halt_active)
+	action = HALT;
+      else if (reboot_active)
+	action = REBOOT;
       retval = TRUE;
       break;
     default:
@@ -340,13 +324,33 @@ display_gui (void)
       retval= FALSE;
       break;
     case GTK_RESPONSE_HELP:
-      gnome_help_display("panelbasics.html#LOGGINGOUT", NULL, NULL);
+      gnome_help_display_desktop (NULL, "user-guide", "wgosstartsession.xml",
+				  "gosgetstarted-73", &error);
+
+      if (error) 
+        {
+          GtkWidget *dialog;
+
+          dialog = gtk_message_dialog_new (GTK_WINDOW (box),
+        				   GTK_DIALOG_DESTROY_WITH_PARENT,
+        				   GTK_MESSAGE_ERROR,
+        				   GTK_BUTTONS_CLOSE,
+        				   ("There was an error displaying help: \n%s"),
+        				   error->message);
+
+          g_signal_connect (G_OBJECT (dialog), "response",
+	   		    G_CALLBACK (gtk_widget_destroy),
+			    NULL);
+
+          gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+          gtk_widget_show (dialog);
+          g_error_free (error);
+        }
+   
       retval = FALSE;
       break;
     }
 
-  gtk_widget_destroy (box);
-
   return retval;
 }
 
